##  First Steps To Realize Value With SAP LeanIX Architecture and Road Map Planning
The following sections guide you through the initial steps of your SAP LeanIX Architecture and Road Map Planning onboarding, aimed at unlocking some of the value that the product brings to your transformation process.
To begin with, focus on an initiative that is important for your organization and that your stakeholders already know about. It should be part of a transformation plan, like moving to the cloud or upgrading your ERP system, etc. This way, your first step with SAP LeanIX Architecture and Road Map Planning is tied to something concrete and valuable for the whole organization.
At the end of the SAP LeanIX Architecture and Road Map Planning onboarding, you will have achieved the following:
  * End-to-end application of all SAP LeanIX Architecture and Road Map Planning features
  * Created high-level Initiatives with Sub-Initiatives or Projects
  * Created Milestones and established depedencies
  * Created Transformations with Impacts
  * Gained valuable insights on the future states for your Initiative via a Project Roadmap Report (with drill-down to Applications, Transformations, Impacts, showing dependencies) and future-state views of your architecture via the Application Landscape Report
  * Have a governance and collaboration model in place with your Project Manager organization to ensure that data will be kept up-to-date
  * Plan to roll out Architecture and Road Map Planning to the broader organization for your transformation program
